@@ -1,5 +1,5 @@
 #!/bin/sh
-# $Id: jailup.sh,v 1.3 2003/01/15 02:07:44 babolo Exp $
+# $Id: jailup.sh,v 1.6 2003/05/03 03:17:49 babolo Exp $
 export PATH=/bin
 
 if  [ -r /etc/defaults/rc.conf ]; then
@@ -23,4 +23,13 @@ fi
 . ${JAILUP_CONF}
 
 echo ' jailup'
-${PREFIX}/sbin/jailupctl "$@"
+case ${1} in
+start)
+    shift
+    ${PREFIX}/sbin/jailupctl restop "$@" > /dev/null 2>&1
+    ${PREFIX}/sbin/jailupctl start  "$@"
+    ;;
+*)
+    ${PREFIX}/sbin/jailupctl "$@"
+    ;;
+esac
